/* compinfo.c */

/* Print info about a VIS-5D compressed grid file.

   Usage:
      compinfo COMPfile

   where:
      COMPfile is the name of a VIS-5D compressed grid file.

*/




#include <stdio.h>
#include "fileio.h"


/* New VIS-5D version 3.0 limits: */
#define MAXTIMES 400
#define MAXPARMS 30



main( argc, argv )
int argc;
char *argv[];
{
   FILE *f;
   int i, id;
   int numtimes, numparms, nr, nc, nl;
   float northlat, westlon, tophgt, latinc, loninc, hgtinc;
   int daystamp[MAXTIMES], timestamp[MAXTIMES];
   char parmname[MAXPARMS][5];
   int FileTimes, FileParms;

   if (argc==1) {
      printf("Usage:\n");
      printf("   compinfo COMPfile\n");
      exit(1);
   }

   if (f=fopen(argv[1],"r")) {
      read_int4( f, &id );
      if (id==0x80808080) {
	 printf("Old VIS-5D format (max. 300 times, 20 variables)\n");
	 FileTimes = 300;
	 FileParms = 20;
      }
      else if (id=0x80808081) {
	 printf("New VIS-5D format (max. 400 times, 30 variables)\n");
	 FileTimes = 400;
	 FileParms = 30;
      }
      else {
	 printf("ERROR:  %s is not a VIS-5D compressed grid file\n", argv[1]);
	 exit(1);
      }
      read_int4( f, &numtimes );
      read_int4( f, &numparms );
      read_int4( f, &nr );
      read_int4( f, &nc );
      read_int4( f, &nl );
      read_float4( f, &northlat );
      read_float4( f, &westlon );
      read_float4( f, &tophgt );
      read_float4( f, &latinc );
      read_float4( f, &loninc );
      read_float4( f, &hgtinc );
      for (i=0;i<FileTimes;i++) {
	 read_int4( f, &daystamp[i] );
      }
      for (i=0;i<FileTimes;i++) {
	 read_int4( f, &timestamp[i] );
      }
      for (i=0;i<FileParms;i++) {
	 read_bytes( f, parmname[i], 4 );
	 parmname[i][4] = 0;
      }

      fclose(f);

      printf("Rows: %d  Columns: %d  Levels: %d\n", nr, nc, nl );
      printf("NorthLat: %f deg  LatInc: %f deg  (SouthLat: %f deg)\n",
	     northlat, latinc, northlat-(latinc*(nr-1)) );
      printf("WestLon: %f deg  LonInc: %f deg  (EastLon: %f deg)\n",
	     westlon, loninc, westlon-(loninc*(nc-1)) );
      printf("Top: %f km  TopInc: %f km  (Bottom: %f km)\n",
	     tophgt, hgtinc, tophgt-(hgtinc*(nl-1)) );
      printf("Number of variables:   %d\n", numparms );
      printf("Variables: ");
      for (i=0;i<numparms;i++) {
	 printf("%s ", parmname[i] );
      }
      printf("\n");
      printf("Number of time steps:  %d\n", numtimes );

   }
}







